.. title:: Instant


=======
Instant
=======

Instant is a Python module that allows for instant inlining of C and
C++ code in Python. It is a small Python module built on top of SWIG
and Distutils.

Instant is part of the FEniCS Project.

For more information, visit http://www.fenicsproject.org.


Documentation
=============

.. toctree::
   :titlesonly:
   :maxdepth: 1

   installation
   manual
   API reference <api-doc/instant>
   releases

[FIXME: These links don't belong here, should go under API reference somehow.]

* :ref:`genindex`
* :ref:`modindex`
